@@ -5,10 +5,13 @@ import os
 import sys
 from os import path
 #sys.path.append(path.dirname(path.dirname(path.dirname(path.abspath(__file__)))))
+#sys.path.insert(0, os.path.abspath('./harmon/'))
+
 #CONFIG_FILE=os.path.join(sys.path[-1],"streams_cca.yaml")
 env_conf = os.getenv("HARMONCONF_YML")
 if env_conf is None:
-    CONFIG_FILE="streams.yaml"
+    basedir = f'{os.path.abspath(__file__+"/..")}'
+    CONFIG_FILE=f"{basedir}/streams.yaml"
 else:
     CONFIG_FILE=env_conf
 
